# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/tesr/test1/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Tesr\\Test1\\": "packages/tesr/test1/src",
            "Tesr\\Test1\\Seeders\\": "packages/tesr/test1/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Tesr\Test1\Providers\Test1ServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Test1'  => Tesr\Test1\Facades\Test1::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Tesr\\Test1\\Seeders\\Test1TableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Tesr\Test1\Providers\Test1ServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Tesr\Test1\Providers\Test1ServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Tesr\Test1\Providers\Test1ServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/test1/{modulename}

**User**

    http://path-to-route-folder/user/test1/{modulename}

**Public**

    http://path-to-route-folder/test1s


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/test1/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/test1/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/test1/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/test1/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/test1/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/test1/{modulename}/{slug}
    METHOD: GET