<?php

namespace Tesr\Test1\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Tesr\Test1\Http\Requests\CustomermasterRequest;
use Tesr\Test1\Models\Customermaster;

/**
 * Admin web controller class.
 */
class CustomermasterWorkflowController extends BaseController
{

    /**
     * Workflow controller function for customermaster.
     *
     * @param Model   $customermaster
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(CustomermasterRequest $request, Customermaster $customermaster, $step)
    {

        try {

            $customermaster->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('test1::customermaster.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/customermaster/customermaster/' . $customermaster->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/customermaster/customermaster/' . $customermaster->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for customermaster.
     *
     * @param Model   $customermaster
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Customermaster $customermaster, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $customermaster->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('test1::customermaster.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('test1::admin.customermaster.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('test1::admin.customermaster.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('test1::admin.customermaster.message', $data)->render();

        }

    }
}
