<?php

namespace Tesr\Test1\Providers;

use Illuminate\Support\ServiceProvider;
use Tesr\Test1\Test1s;

class Test1ServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'test1');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'test1');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();

        $this->app->register(\Tesr\Test1\Providers\AuthServiceProvider::class);
        $this->app->register(\Tesr\Test1\Providers\RouteServiceProvider::class);
        // $this->app->register(\Tesr\Test1\Providers\EventServiceProvider::class);
        // $this->app->register(\Tesr\Test1\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('tesr.test1', function($app)
        {
            return $this->app->make(Test1s::class);
        });
    }

    /**
     * Register the bindings for the service provider.
     *
     * @return void
     */
    public function registerBindings() {
                // Bind Customermaster to repository
        $this->app->bind(
            'Tesr\Test1\Interfaces\CustomermasterRepositoryInterface',
            \Tesr\Test1\Repositories\Eloquent\CustomermasterRepository::class
        );
    }


    /**
     * Merges user's and test1's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'tesr.test1'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Tesr\Test1\Commands\Test1::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['tesr.test1'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('tesr/test1.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/test1')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/test1')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
